import React, { FC } from 'react';
import { Image, TouchableOpacity, View } from 'react-native';
import { ImageItemButtonModel } from '../../listItemModels';
import { Body2RegularText, ChevronRightIcon, LabelSemiBoldText } from '../../../../atoms';
import { styles } from './styles';

export const HeaderArticleButton: FC<ImageItemButtonModel> = ({
  text,
  description,
  disabled,
  imageURL,
  onClick,
}) => {
  return (
    <TouchableOpacity
      disabled={disabled}
      onPress={onClick}
      style={styles.headerArticleButton}
    >
      <>
        {!!imageURL &&
          <Image
            style={styles.headerArticleButtonImage}
            source={{ uri: imageURL }}
          />}
        {!imageURL &&
          <View
            style={styles.headerArticleButtonImage}
          />}
        <View style={styles.headerArticleButtonInfoContainer}>
          <View style={styles.headerArticleButtonInfoTextContainer}>
            <LabelSemiBoldText numberOfLines={1} color={styles.headerArticleButtonInfoTextContainer.text.color}>
              {text}
            </LabelSemiBoldText>
            <Body2RegularText
              numberOfLines={1}
              color={styles.headerArticleButtonInfoTextContainer.description.color}
            >
              {description}
            </Body2RegularText>
          </View>
          <View style={styles.headerArticleButtonInfoIconContainer}>
            <ChevronRightIcon height={32} width={32} />
          </View>
        </View>
      </>
    </TouchableOpacity>
  );
};
