import React, { FC } from 'react';
import { Dimensions, TouchableOpacity, View } from 'react-native';
import { BottomSheet } from './components';
import { BottomSheetNavigationWrapperModel } from '../modalWrapperModels';

const windowHeight = Dimensions.get('window').height;

export const BottomSheetNavigationWrapper: FC<BottomSheetNavigationWrapperModel> = ({
  onCloseModal,
  isVisible = true,
  modalHeight,
  children,
  showDragBar,
}) => {
  const defaultModalHeight: number = typeof modalHeight === 'string'
    ? windowHeight * (parseFloat(modalHeight)/100)
    : modalHeight;

  return (
    <View style={{ backgroundColor: 'transparent', height: windowHeight  }}>
      <TouchableOpacity style={{ height: windowHeight }} onPress={onCloseModal} />
      <BottomSheet
        isVisible={isVisible}
        defaultHeight={defaultModalHeight}
        onClose={onCloseModal}
        showDragBar={showDragBar}
      >
        {children}
      </BottomSheet>
    </View>
  );
};
