import React, { FC } from 'react';
import { View } from 'react-native';
import { CalendarDate } from '../calendarDate';
import { CalendarDisabledDate } from '../calendarDisabledDate';
import { DateCategory, DateNumberOfTheMonth, DateOfTheMonthData } from '../../calendarModel';
import { styles } from './styles';

interface CalendarMonthDaysProps {
  datesData: DateOfTheMonthData[];
  onDatePress?: (numberDay: DateNumberOfTheMonth) => void;
  disabled?: boolean;
}

export const CalendarMonthDates: FC<CalendarMonthDaysProps> = ({ datesData, onDatePress }) => (
  <View style={styles.calendarMonthDatesWrapper}>
    {datesData.map(({ dateCategories, dateNumber, key }) => {
      const isDisabledDate = dateCategories.some(category => DateCategory.DISABLED === category);

      return (
        <View key={key} style={styles.monthDate}>
          {isDisabledDate && (
            <CalendarDisabledDate dateNumber={dateNumber} />
          )}
          {!isDisabledDate && (
            <CalendarDate category={dateCategories} dateNumber={dateNumber} onDateNumberClick={onDatePress} />
          )}
        </View>
      );
    })}
  </View>
);
