import { MonthNumberAndYear,
  PressControlOptions,
  MonthNumber } from '../calendarModel';

interface PressControlManager {
  previousYear: (monthNumber: MonthNumber, year: number) => MonthNumberAndYear;
  previousMonth: (monthNumber: MonthNumber, year: number) => MonthNumberAndYear;
  nextMonth: (monthNumber: MonthNumber, year: number) => MonthNumberAndYear;
  nextYear: (monthNumber: MonthNumber, year: number) => MonthNumberAndYear;
}

export const pressControlManager: PressControlManager = {
  [PressControlOptions.PREVIOUS_YEAR]: (monthNumber, year) => ({
    monthNumber,
    year: year - 1,
  }),
  [PressControlOptions.PREVIOUS_MONTH]: (monthNumber, year) => ({
    monthNumber: monthNumber === 1 ? 12 : monthNumber - 1 as MonthNumber,
    year: monthNumber === 1 ? year - 1 : year,
  }),
  [PressControlOptions.NEXT_MONTH]: (monthNumber, year) => ({
    monthNumber: monthNumber === 12 ? 1 : monthNumber + 1 as MonthNumber,
    year: monthNumber === 12 ? year + 1 : year,
  }),
  [PressControlOptions.NEXT_YEAR]: (monthNumber, year) => ({
    monthNumber,
    year: year + 1,
  }),
};

type GetSelectedDate = (params : {
  pressControlOption: PressControlOptions;
  selectedMonthNumber: MonthNumber;
  selectedYear: number;
}) => MonthNumberAndYear;

export const getSelectedDate: GetSelectedDate = ({
  pressControlOption, 
  selectedMonthNumber, 
  selectedYear,
}) => {
  return pressControlManager[pressControlOption](selectedMonthNumber, selectedYear);
};
