import React, { FC, useEffect } from 'react';
import { View } from 'react-native';
import { GradualShutterWithSlatsWidgetDetailModel } from '../../widgetDetailModels';
import { ShutterControlPanel } from '../components/shutterControlPanel';
import { ShutterQuickActions } from '../components/shutterQuickActions';
import { ShutterAction, SlatsAction } from '../components/shutterModels';
import { useShutter } from '../hooks/useShutter';
import { SlatsControlPanel } from '../components/slatsControlPanel';
import { useSlats } from '../hooks/useSlats';

const getNumberFromValue = (value: string) => Number(value);
const getStringFromActionResult = (result: number) => String(result);

export const GradualShutterWithSlatsWidgetDetail: FC<GradualShutterWithSlatsWidgetDetailModel> = ({
  shutterId,
  slatsId,
  shutterValue = '0',
  slatsValue = '0',
  widgetName,
  widgetInfoTextOptions,
  quickActionsTitle,
  quickActionButtonsTextOptions,
  shutterControlPanelTitle,
  slatsControlPanelTitle,
  loadingInfoTextOptions,
  onUpdateData,
  loading = false,
}) => {
  const { shutterOutputValue, onShutterAction, shutterOngoingAction } = useShutter(getNumberFromValue(shutterValue));
  const { fixedSlatsValue, setSlatsValue, onSlatsAction } = useSlats();
  const buttonOneText = quickActionButtonsTextOptions?.open;
  const buttonTwoText = quickActionButtonsTextOptions?.close;

  const onChangeShutterValue = (action: ShutterAction) => {
    const resultAfterAction = onShutterAction(action);
    onUpdateData?.({ id: shutterId, value: getStringFromActionResult(resultAfterAction) });
  };

  const onChangeSlatsValue = (action: SlatsAction) => {
    const resultAfterAction = onSlatsAction(getNumberFromValue(slatsValue), action);
    slatsValue && onUpdateData?.({ id: slatsId, value: getStringFromActionResult(resultAfterAction) });
  };

  useEffect(() => {
    setSlatsValue(getNumberFromValue(slatsValue));
  }, [slatsValue]);

  return (
    <View>
      <ShutterQuickActions
        title={quickActionsTitle}
        value={shutterOutputValue}
        buttonOneText={buttonOneText}
        buttonTwoText={buttonTwoText}
        onClick={onChangeShutterValue}
        loading={loading}
      />
      <ShutterControlPanel
        title={shutterControlPanelTitle}
        widgetName={widgetName}
        widgetStateInfoOptions={widgetInfoTextOptions}
        loadingInfoTextOptions={loadingInfoTextOptions}
        value={shutterOutputValue}
        ongoingAction={shutterOngoingAction}
        onClick={onChangeShutterValue}
        loading={loading}
      />
      <SlatsControlPanel
        title={slatsControlPanelTitle}
        value={fixedSlatsValue}
        onClick={onChangeSlatsValue}
        loading={loading}
      />
    </View>
  );
};
