import { ShutterInfoTextOptionsModel } from './shutter/components/shutterModels';

export type BinaryDefaultValue = 'ON' | 'OFF';
export type TripleDefaultValue = 'ON' | 'OFF' | 'EMPTY';
export type WidgetDetailBinaryValue = 'ON' | 'OFF';

export interface WidgetDetailModel {
  id: string;
  title?: string;
  subtitle?: string; 
  loadingInfoTextOptions?: LoadingInfoTextModel;
  value?: string;
  defaultValue?: string;
  onUpdateData?: (item: {id: string, value: string}) => void;
  loading?: boolean;
}

export interface BinaryDoorWidgetDetailModel extends Omit<WidgetDetailModel, 'defaultValue' | 'value'>
{ defaultValue?: BinaryDefaultValue }

export interface TripleDoorWidgetDetailModel extends Omit<WidgetDetailModel, 'defaultValue' | 'value'>
{ defaultValue?: TripleDefaultValue }

export interface SwitchWidgetDetailModel extends Omit<WidgetDetailModel, 'defaultValue' | 'subtitle' | 'value'>
{ subtitle?: BinarySubtitleModel, value?: WidgetDetailBinaryValue }


export interface SwitchAndDimmerWidgetDetailModel extends Omit<WidgetDetailModel, 'defaultValue' | 'subtitle' | 'value'>
{ 
  defaultValue?: BinaryDefaultValue,
  subtitle?: BinarySubtitleModel,
  value?: number,
  sliderTitle?: string,
}

export interface GradualShutterWidgetDetailModel extends Omit<WidgetDetailModel, 'defaultValue' | 'subtitle' | 'title' | 'loadingInfoTextOptions'>
{ 
  widgetName?: string,
  widgetInfoTextOptions?: ShutterInfoTextOptionsModel,
  quickActionButtonsTextOptions?: QuickActionButtonsTextModel,
  quickActionsTitle?: string,
  controlPanelTitle?: string,
  loadingInfoTextOptions?: ShutterLoadingInfoTextModel,
}

export interface GradualShutterWithSlatsWidgetDetailModel extends Omit<WidgetDetailModel, 'id' | 'defaultValue' | 'subtitle' | 'title' | 'loadingInfoTextOptions' | 'value'>
{
  shutterId: string,
  slatsId: string,
  widgetName?: string,
  widgetInfoTextOptions?: ShutterInfoTextOptionsModel,
  quickActionButtonsTextOptions?: QuickActionButtonsTextModel,
  quickActionsTitle?: string,
  shutterValue?: string,
  slatsValue?: string,
  loadingInfoTextOptions?: ShutterLoadingInfoTextModel,
  shutterControlPanelTitle?: string,
  slatsControlPanelTitle?: string,
}

export interface LoadingInfoTextModel {
  option1?: string;
  option2?: string;
  option3?: string;
}

export interface ShutterLoadingInfoTextModel {
  opening?: string;
  closing?: string;
  stopping?: string;
}

export interface QuickActionButtonsTextModel {
  open?: string;
  close?: string;
}

export interface BinarySubtitleModel {
  on?: string;
  off?: string;
}

